/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*
 * Monitor.java,v 1.2 2002/08/02 15:39:11 jba Exp
 */

package jca;

import jca.event.*;

/*
 * This class allows users to keep track of their monitors.
 * 
 * @see jca.PV.addMonitor
 */
public class Monitor extends Object {
  /**
   * The monitor is triggered when the PV value change.
   */
  public static final int VALUE             = 1;
  /**
   * The monitor is triggered when the PV log value change.
   */
  public static final int LOG               = 2;
  /**
   * The monitor is triggered when the PV alarm state change.
   */
  public static final int ALARM             = 4;

  protected jca.event.MonitorEvent m_event;

  protected Monitor(jca.event.MonitorEvent e) {
    m_event= e;
  }

  /**
   * Clear the monitor.
   *
   * @exception jca.BadMonitorException thrown if the monitor has already been cleared.
   */
  public void clear() throws jca.BadMonitorException {
    if(m_event.id()<0) throw new jca.BadMonitorException();
    Ca.clearMonitor(this);
  }

  /**
   * Return the monitor ID. All Monitor have their own ID.
   */
  public int id() {
    return m_event.id();
  }
}
