/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*
 * DBR_CTRL_DBDouble.java,v 1.2 2002/08/02 15:39:13 jba Exp
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_CTRL_DOUBLE type.
 *
 */
public class DBR_CTRL_DBDouble extends DBR_GR_DBDouble implements DBR_CTRL {
  private double   m_upper_ctrl_limit;
  private double   m_lower_ctrl_limit;

  /**
   * Create a new DBR_CTRL_DBDouble object to hold 1 double.
   */
  public DBR_CTRL_DBDouble() {
    super(1);
  }
  
  /**
   * Create a new DBR_CTRL_DBDouble object to hold count double.
   *
   * @param count the number of double to be hold by this object.
   */
  public DBR_CTRL_DBDouble(int count) {
    super(count);
  }

  /**
   * Return the Channel Access request type.
   */
  public int type() {
    return DBR.CTRL_DOUBLE;
  }

  /**
   * Return the upper control limit.
   */
  public DBData upperCtrlLimit() {
    return new DBDouble(m_upper_ctrl_limit);
  }

  /** 
   * Return the lower control limit.
   */
  public DBData lowerCtrlLimit() {
    return new DBDouble(m_lower_ctrl_limit);
  }

  protected void setInfo(short status, short severity,
                         short precision,
                         String units,
                         double upper_disp_limit,
                         double lower_disp_limit,
                         double upper_alarm_limit,
                         double upper_warning_limit,
                         double lower_warning_limit,
                         double lower_alarm_limit,
                         double upper_ctrl_limit,
                         double lower_ctrl_limit) {
    super.setInfo(status,severity, 
                  precision,
                  units,
                  upper_disp_limit,
                  lower_disp_limit,
                  upper_alarm_limit,
                  upper_warning_limit,
                  lower_warning_limit,
                  lower_alarm_limit);
    m_upper_ctrl_limit= upper_ctrl_limit;
    m_lower_ctrl_limit= lower_ctrl_limit;
  };                      
}
