/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*
 * TimeStamp.java,v 1.3 2002/08/02 15:39:21 jba Exp
 */

package jca.misc;

import jca.event.*;
import jca.dbr.*;
import java.lang.*;
import java.util.*;
import java.awt.event.*;



public class TimeStamp {

  public TimeStamp() {
    long millis= System.currentTimeMillis();
    secPastEpoch= millis/1000 - TS_EPOCH_SEC_PAST_1970;
    nsec= (millis%1000)*1000000;
  }

  public TimeStamp(long secPastEpoch, long nsec) {
    this.secPastEpoch= secPastEpoch;
    this.nsec= nsec;
  }

  public TimeStamp(double dbl) {
    secPastEpoch= (long) dbl;
    nsec= (long)((dbl - (double)secPastEpoch)*1000000000.0);
  }

  public TimeStamp(TimeStamp ts) {
    secPastEpoch= ts.secPastEpoch;
    nsec= ts.nsec;
  }

  public void add(double dbl) {
    long secPastEpoch,nsec;
    if(dbl>=0.) {
      secPastEpoch= (long)dbl;
      nsec= (long) ((dbl-(double)secPastEpoch)*1000000000.0);
      add(secPastEpoch, nsec);
    } else {
      secPastEpoch= (long)-dbl;
      nsec= (long)((-dbl-(double)secPastEpoch)*1000000000.0);
      sub(secPastEpoch, nsec);
    }
  }

  public void add(TimeStamp ts) {
    add(ts.secPastEpoch, ts.nsec);
  }

  public void sub(double dbl) {
    add(-dbl);
  }

  public void sub(TimeStamp ts) {
    sub(ts.secPastEpoch, ts.nsec);
  }


  public int cmp(TimeStamp ts) {
    if(secPastEpoch<ts.secPastEpoch) return -1;
    else if(secPastEpoch==ts.secPastEpoch) {
      if(nsec<ts.nsec) return -1;
      else if(nsec==ts.nsec) return 0;
      else return 1;
    } else return 1;
  }

  public boolean EQ(TimeStamp ts) {
    return ((secPastEpoch==ts.secPastEpoch) && (nsec==ts.nsec));
  }

  public boolean NE(TimeStamp ts) {
    return ((secPastEpoch!=ts.secPastEpoch) || (nsec!=ts.nsec));
  }
    
  public boolean GT(TimeStamp ts) {
    if(secPastEpoch>ts.secPastEpoch) return true;
    return ((secPastEpoch==ts.secPastEpoch) && (nsec>ts.nsec));
  }

  public boolean GE(TimeStamp ts) {
    if(secPastEpoch>ts.secPastEpoch) return true;
    return ((secPastEpoch==ts.secPastEpoch) && (nsec>=ts.nsec));
  }

  public boolean LT(TimeStamp ts) {
    if(secPastEpoch<ts.secPastEpoch) return true;
    return ((secPastEpoch==ts.secPastEpoch) && (nsec<ts.nsec));
  }

  public boolean LE(TimeStamp ts) {
    if(secPastEpoch<ts.secPastEpoch) return true;
    return ((secPastEpoch==ts.secPastEpoch) && (nsec<=ts.nsec));
  }

  public double asDouble() {
    return ((double)secPastEpoch + (double)nsec/1000000000.0);
  }

  public String toMMDDYY() {
    int month;
    int day;
    int year;
    int hours;
    int minutes;
    int seconds;
    Date date= new Date((secPastEpoch+TS_EPOCH_SEC_PAST_1970)*1000+nsec/1000000);
    Calendar cal= Calendar.getInstance();
    cal.setTime(date);

    StringBuffer buff= new StringBuffer(40);
    String fracPart= format(9, nsec);
    if(nsec % 1000000 == 0)   fracPart= fracPart.substring(0,3);
    else if(nsec % 1000 == 0) fracPart= fracPart.substring(0,6);


    if(secPastEpoch<=86400) {
      hours  = (int) (secPastEpoch / 3600);
      minutes= (int) ((secPastEpoch / 60) % 60);
      seconds= (int) (secPastEpoch % 60);
    } else {
      month= cal.get(Calendar.MONTH)+1;
      day= cal.get(Calendar.DAY_OF_MONTH);
      year= cal.get(Calendar.YEAR) % 100 ;
      hours= cal.get(Calendar.HOUR_OF_DAY);
      minutes= cal.get(Calendar.MINUTE);
      seconds= cal.get(Calendar.SECOND);
      buff.append(format(2,month));
      buff.append(":");
      buff.append(format(2,day));
      buff.append(":");
      buff.append(format(2,year));
      buff.append(" ");
    }
    buff.append(format(2,hours));
    buff.append(":");
    buff.append(format(2,minutes));
    buff.append(":");
    buff.append(format(2,seconds));
    buff.append(".");
    buff.append(fracPart);

    return buff.toString();
  }

  public String toMONDDYYYY() {
    int month;
    int day;
    int year;
    int hours;
    int minutes;
    int seconds;
    Date date= new Date((secPastEpoch+TS_EPOCH_SEC_PAST_1970)*1000+nsec/1000000);
    Calendar cal= Calendar.getInstance();
    cal.setTime(date);

    StringBuffer buff= new StringBuffer(40);
    String fracPart= format(9, nsec);
    if(nsec % 1000000 == 0)   fracPart= fracPart.substring(0,3);
    else if(nsec % 1000 == 0) fracPart= fracPart.substring(0,6);


    if(secPastEpoch<=86400) {
      hours  = (int) (secPastEpoch / 3600);
      minutes= (int) ((secPastEpoch / 60) % 60);
      seconds= (int) (secPastEpoch % 60);
    } else {
      month= cal.get(Calendar.MONTH);
      day= cal.get(Calendar.DAY_OF_MONTH);
      year= cal.get(Calendar.YEAR);
      hours= cal.get(Calendar.HOUR_OF_DAY);
      minutes= cal.get(Calendar.MINUTE);
      seconds= cal.get(Calendar.SECOND);
      buff.append(monthText[month]);
      buff.append(" ");
      buff.append(format(2,day));
      buff.append(",");
      buff.append(format(2,year));
      buff.append(" ");
    }
    buff.append(format(2,hours));
    buff.append(":");
    buff.append(format(2,minutes));
    buff.append(":");
    buff.append(format(2,seconds));
    buff.append(".");
    buff.append(fracPart);

    return buff.toString();
  }



  public static TimeStamp add(TimeStamp ts, double dbl) {
    TimeStamp res= new TimeStamp(ts);
    res.add(dbl);
    return res;
  }

  public static TimeStamp add(TimeStamp ts1, TimeStamp ts2) {
    TimeStamp res= new TimeStamp(ts1);
    res.add(ts2);
    return res;
  }

  public static TimeStamp sub(TimeStamp ts, double dbl) {
    TimeStamp res= new TimeStamp(ts);
    res.sub(dbl);
    return res;
  }

  public static TimeStamp sub(TimeStamp ts1, TimeStamp ts2) {
    TimeStamp res= new TimeStamp(ts1);
    res.sub(ts2);
    return res;
  }


  public static void main(String[] args) {
    TimeStamp ts= new TimeStamp(86500, 0);
    System.out.println(ts.toMONDDYYYY());
    System.out.println(ts.toMMDDYY());
    ts= new TimeStamp();
    System.out.println(ts.toMONDDYYYY());
    System.out.println(ts.toMMDDYY());
  }



  private void add(long secPastEpoch, long nsec) {
    this.secPastEpoch+= secPastEpoch;
    if((this.nsec+= nsec)>=1000000000) {
      this.secPastEpoch+= this.nsec/1000000000;
      this.nsec%= 1000000000;
    }
  }

  private void sub(long secPastEpoch, long nsec) {
    this.secPastEpoch-= secPastEpoch;
    if(this.nsec>=nsec) {
      this.nsec-=nsec;
    } else {
      this.nsec+=1000000000-nsec;
      --this.secPastEpoch;
    }
  }

  private String format(int width, int value) {
    StringBuffer buff= new StringBuffer();
    buff.append(value);
    while(buff.length()<width) buff.insert(0, "0");
    return buff.toString();
  }

  private String format(int width, long value) {
    StringBuffer buff= new StringBuffer();
    buff.append(value);
    while(buff.length()<width) buff.insert(0, "0");
    return buff.toString();
  }


  private long secPastEpoch;
  private long nsec;

  private static long TS_EPOCH_YEAR         =1990;
  private static long TS_EPOCH_SEC_PAST_1970=7305*86400;
  private static long TS_EPOCH_WDAY_NUM     =1;

  private static String[] monthText= { "Jan", "Feb", "Mar", "Apr",
                                       "May", "Jun", "Jul", "Aug",
                                       "Sep", "Oct", "Nov", "Dec" };

};







