/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/


import java.lang.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import jca.*;
import jca.event.*;
import jca.dbr.*;





public class Test
  implements GetListener, PutListener, MonitorListener, ConnectionListener {

  public static int m_done= 0;
  public static boolean m_connected= false;
  
  public void connectionChanged(ConnectionEvent e) {
    System.out.println("Connection changed : "+ e.pv().name());
    if(e.op()==6) {
      m_connected= true;
    }
  }

  public void getCompleted(GetEvent e) {
    System.out.println("Get completed : "+ e.pv().name());
    switch(e.dbr().type()) {
    case DBR.STS_SHORT: 
      DBR_STS dbr= (DBR_STS)e.dbr();
      System.out.println("\nstatus   : "+dbr.status()+
                         "\nseverity : "+dbr.severity()+
                         "\nvalue[0] : "+dbr.dataAt(0).doubleValue());
      break;
    }
    --m_done;
  }

  public void putCompleted(PutEvent e) {
    System.out.println("Put completed : "+ e.pv().name());
    --m_done;
  }    

  public void monitorChanged(MonitorEvent e) {
    System.out.println("Event occured : "+ e.pv().name());
  }


  public static void main(String[] args) {

    if(args.length<1) {
      System.out.println("usage: java Test pvname");
      return;
    }

    Test T= new Test();

    Ca.init();

    System.out.println("Connecting to "+ args[0]);
    PV pv1= new PV(args[0],null,T);

    try {
      while(!m_connected) {
        Ca.pendEvent(1.0);
      }
      pv1.setConnectionListener(null);

      System.out.println("field type    : "+pv1.fieldType());
      System.out.println("element count : "+pv1.elementCount());
      System.out.println("name          : "+pv1.name());
      System.out.println("state         : "+pv1.state());
      System.out.println("host name     : "+pv1.hostName());
      System.out.println("read access   : "+pv1.readAccess());
      System.out.println("write access  : "+pv1.writeAccess());
      
      System.out.println("Adding event");
      Monitor m1= pv1.addMonitor(new DBR_DBString(), T, null, Monitor.VALUE);
      
      System.out.println("puting 12");
      pv1.put("12");
      DBR_DBShort val= new DBR_DBShort(1);
      pv1.get(val);
      
      Ca.pendIO(1.0);
      
      System.out.println("pv1 : "+val.valueAt(0));
      
      pv1.put("100");
      Ca.pendIO(1.0);
      
      m1.clear();
      Ca.pendIO(1.0);
      
      System.out.println("");
      System.out.println("");
      System.out.println("");
      
      System.out.println("GetCallback");
      pv1.get(new DBR_STS_DBShort(),T,"get_callback");
      ++m_done;
      
      System.out.println("PutCallback");
      pv1.put("10",T,"put_callback");
      ++m_done;
      
      

      while(m_done!=0) {
        Ca.pendEvent(1.0);
      }
      
      PV x= new PV(args[0]);
      Ca.pendIO(1.0);
      DBR_CTRL_DBInt xval= new DBR_CTRL_DBInt();
      x.get(xval);
      Ca.pendIO(2.0);
      System.out.println("Value         : "+xval.valueAt(0));
      System.out.println("Status        : "+xval.status());
      System.out.println("Severity      : "+xval.severity());
      System.out.println("units         : "+xval.units());
      System.out.println("upper disp    : "+xval.upperDispLimit().intValue());
      System.out.println("lower disp    : "+xval.lowerDispLimit().intValue());
      System.out.println("upper alarm   : "+xval.upperAlarmLimit().intValue());
      System.out.println("upper warning : "+xval.upperWarningLimit().intValue());
      System.out.println("lower warning : "+xval.lowerWarningLimit().intValue());
      System.out.println("lower alarm   : "+xval.lowerAlarmLimit().intValue());
      System.out.println("upper ctrl    : "+xval.upperCtrlLimit().intValue());
      System.out.println("lower ctrl    : "+xval.lowerCtrlLimit().intValue());
                


    } catch(CaException e) {
      System.out.println(e);
    }


    Ca.exit();
    System.out.println("End !!!");

  }
}


